@@ -291,7 +291,7 @@ def query_snowflake(query, creds_dict=None):
 
     '''
 
-    try:
+    if creds_dict is None:
         creds_dict = {
             'usr' : os.environ.get('SNOWFLAKE_USR'),
             'pwd' : os.environ.get('SNOWFLAKE_PWD'),
@@ -300,8 +300,10 @@ def query_snowflake(query, creds_dict=None):
             'db_name' : os.environ.get('SNOWFLAKE_DB_NAME'),
             'schema' : os.environ.get('SNOWFLAKE_SCHEMA')
         }
-    except all(value is None for value in creds_dict.values()):
-        creds_dict = settings.SNOWFLAKE_FPA
+
+        #Use settings if ENV vars are not set up
+        if all(value is None for value in creds_dict.values()):
+            creds_dict = settings.SNOWFLAKE_FPA
 
     conn = get_snowflake_connection(**creds_dict)
 
@@ -332,16 +334,18 @@ def query_redshift(query, dsn_dict=None, jdbc_driver_loc=None):
     '''
 
     if dsn_dict is None:
-        try:
-            acct = {
+    
+        acct = {
             #REDSHIFT CREDS
             'dsn_database' : os.environ.get('REDSHIFT_DB'),
             'dsn_hostname' : os.environ.get('REDSHIFT_HOST'),
             'dsn_port' : os.environ.get('REDSHIFT_PORT'),
             'dsn_uid' : os.environ.get('REDSHIFT_USR'),
             'dsn_pwd' : os.environ.get('REDSHIFT_PWD')
-            }
-        except all(value is None for value in acct.values()):
+        }
+
+        #If ENV vars are not set up, use settings
+        if all(value is None for value in acct.values()):
             acct = settings.REDSHIFT_SVC_ACCT
     else:
         acct = dsn_dict
@@ -396,13 +400,14 @@ def query_databricks(query, databricks_dict=None):
     """
 
     if databricks_dict is None:
-        try:
-            creds = {
-                'server_hostname' : os.environ.get('DB_HOST'),
-                'http_path' : os.environ.get('DB_PATH'),
-                'access_token' : os.environ.get('DB_TOKEN')
-            }
-        except all(value is None for value in creds.values()):
+        creds = {
+            'server_hostname' : os.environ.get('DB_HOST'),
+            'http_path' : os.environ.get('DB_PATH'),
+            'access_token' : os.environ.get('DB_TOKEN')
+        }
+
+        #IF ENV VARS are not set up, use settings
+        if all(value is None for value in creds.values()):
             creds = settings.DATABRICKS_CREDS
     else:
         creds = databricks_dict
